@@ -7,10 +7,12 @@
 
 //! The representation for the label of a history tree node.
 
-use crate::serialization::from_digest;
+use crate::errors::HistoryTreeNodeError;
+use crate::serialization::{digest_deserialize, digest_serialize, from_digest};
 use crate::storage::types::StorageType;
 use crate::storage::Storable;
 use crate::{Direction, ARITY};
+use rand::{CryptoRng, RngCore};
 use serde::{Deserialize, Serialize};
 use std::{
     convert::TryInto,
@@ -18,14 +20,14 @@ use std::{
 };
 use winter_crypto::Hasher;
 
-use rand::{CryptoRng, RngCore};
-
 /// Represents a node's label & associated hash
-#[derive(Debug)]
+#[derive(Debug, Serialize, Deserialize, PartialEq)]
 pub struct Node<H: Hasher> {
     /// the label associated with the accompanying hash
     pub label: NodeLabel,
     /// the hash associated to this label
+    #[serde(serialize_with = "digest_serialize")]
+    #[serde(deserialize_with = "digest_deserialize")]
     pub hash: H::Digest,
 }
 
@@ -162,7 +164,7 @@ impl NodeLabel {
         if other.get_prefix(self.get_len()) != *self {
             return Direction::None;
         }
-        Direction::Some(other.get_bit_at(self.get_len()).try_into().unwrap())
+        Direction::Some(other.get_bit_at(self.get_len()) as usize)
     }
 }
 
@@ -261,13 +263,13 @@ unsafe impl Sync for HistoryNodeState {}
 
 impl HistoryNodeState {
     /// Creates a new [HistoryNodeState]
-    pub fn new<H: Hasher>(key: NodeStateKey) -> Self {
+    pub fn new<H: Hasher>(key: NodeStateKey) -> Result<Self, HistoryTreeNodeError> {
         const INIT: Option<HistoryChildState> = None;
-        HistoryNodeState {
-            value: from_digest::<H>(H::hash(&[0u8])).unwrap(),
+        Ok(HistoryNodeState {
+            value: from_digest::<H>(H::hash(&[0u8]))?,
             child_states: [INIT; ARITY],
             key,
-        }
+        })
     }
 
     /// Returns a copy of the child state, in the calling HistoryNodeState in the given direction.
@@ -291,9 +293,9 @@ impl Clone for HistoryNodeState {
 impl fmt::Display for HistoryNodeState {
     // This trait requires `fmt` with this exact signature.
     fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
-        writeln!(f, "\tvalue = {:?}", self.value).unwrap();
+        writeln!(f, "\tvalue = {:?}", self.value)?;
         for i in 0..ARITY {
-            writeln!(f, "\tchildren {}: {:?}", i, self.child_states[i]).unwrap();
+            writeln!(f, "\tchildren {}: {:?}", i, self.child_states[i])?;
         }
         write!(f, "")
     }
@@ -317,12 +319,16 @@ unsafe impl Sync for HistoryChildState {}
 
 impl HistoryChildState {
     /// Instantiates a new [HistoryChildState] with given label and hash val.
-    pub fn new<H: Hasher>(label: NodeLabel, hash_val: H::Digest, ep: u64) -> Self {
-        HistoryChildState {
+    pub fn new<H: Hasher>(
+        label: NodeLabel,
+        hash_val: H::Digest,
+        ep: u64,
+    ) -> Result<Self, HistoryTreeNodeError> {
+        Ok(HistoryChildState {
             label,
-            hash_val: from_digest::<H>(hash_val).unwrap(),
+            hash_val: from_digest::<H>(hash_val)?,
             epoch_version: ep,
-        }
+        })
     }
 }
 
@@ -602,4 +608,25 @@ mod tests {
             computed
         )
     }
+
+    // Test for serialization / deserialization
+
+    #[test]
+    pub fn serialize_deserialize() {
+        use winter_crypto::hashers::Blake3_256;
+        use winter_crypto::Hasher;
+        use winter_math::fields::f128::BaseElement;
+
+        type Blake3 = Blake3_256<BaseElement>;
+
+        let label = NodeLabel { val: 0, len: 0 };
+        let hash = Blake3::hash(b"hello, world!");
+        let node = Node::<Blake3> { label, hash };
+
+        let serialized = bincode::serialize(&node).unwrap();
+        let deserialized: Node<Blake3> = bincode::deserialize(&serialized).unwrap();
+
+        assert_eq!(node.label, deserialized.label);
+        assert_eq!(node.hash, deserialized.hash);
+    }
 }
